pub struct TcpClientBlocking { /* private fields */ }Expand description
Synchronous TCP subscription listener.
Connects to the TCP server at addr and sends the given subscription request
(encoded as JSON). It then spawns a dedicated thread that reads lines from the TCP
connection using non-blocking mode. If no data is available, it sleeps briefly and
then checks the shutdown flag again.
The listener will continue until either the TCP connection is closed or the provided
shutdown method is called.
Arguments
addr- The address of the TCP subscription server (e.g., “127.0.0.1:9000”).subscription_request- The subscription request to send to the server.
Returns
A Result containing a std::sync::mpsc::Receiver<Event> that will receive events from the server,
or an error.
Implementations